﻿------------------------------------------------------------------------------
-- $Id$
------------------------------------------------------------------------------
--                                templates.lua
--
--    Copyright (C) 2012 Deronda
--
--  This program is free software: you can redistribute it and/or modify
--  it under the terms of the GNU Lesser General Public License as published
--  by the Free Software Foundation, either version 3 of the License, or
--  (at your option) any later version.
--
--  This program is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--  GNU General Public License for more details.
--
--  You should have received a copy of the GNU Lesser General Public License
--  along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
--  This file is for use with clcInfo by abija.  Some of the code was pulled
--  from existing clcInfo modules and the example module.

--  abija has distributed clcInfo All Rights Reserved.  For more information
--  go to: http://wow.curseforge.com/addons/clctracker/
--
------------------------------------------------------------------------------
-- Author:
--      Deronda (@ Stormreaver)
------------------------------------------------------------------------------
-- Description:
--   Templates for clcInfo_Rogue
--------------------------------------------------------------------------------
-- loader
if not clcInfo then return end
if not clcInfo_Rogue then return end

clcInfo.optionsCMLoaders[#(clcInfo.optionsCMLoaders) + 1] = function()
    -- don't load if class is wrong
    local _, englishClass = UnitClass("player")
    if englishClass ~= clcInfo_Rogue.CLASS then return end
    
    local mod = clcInfo_Options.templates
    local defs = mod.defs
    local format = string.format
    
    local spells = clcInfo_Rogue.spells

    local name
    
    --Icons-----------------------------------------------------------
    -- Procs from items or enchants
    
    -- Landslide
    mod:Add("icons", defs.ITEMS_DPS_PHYSICAL, spells["Landslide"].name,
    format([[
    return IconAura("HELPFUL","player","%s")
    ]], spells["Landslide"].name))
    
    --Tier13 2Piece
    mod:Add("icons", defs.ITEMS_DPS_PHYSICAL, spells["Tier13 2P"].name,
    format([[
    return IconAura("HELPFUL","player","%s")
    ]], spells["Tricks of Time"].name))

    -- Kiroptyric Sigil
    mod:Add("icons", defs.ITEMS_DPS_PHYSICAL, (GetItemInfo(77113)),
    format([[
    local visible, texture, start, duration, enable
           = IconAura("HELPFUL", "player", "%s")
    if visible then
        return visible, texture, start, duration, enable
    end
    return IconItem(77113, true)
    ]], spells["Agile"].name))
    
    --Starcatcher Compass
    mod:Add("icons", defs.ITEMS_DPS_PHYSICAL, (GetItemInfo(77202)),
    "return IconMICD(110, 0, 1, 0.3, 109709, 107982, 109789)")
    
    --Vial of Shadows
    mod:Add("icons", defs.ITEMS_DPS_PHYSICAL, (GetItemInfo(77207)),
    "return IconMICD(110, 0, 1, 0.3, 109722, 107995, 109725)")    

    --Wrath of Unchaining
    mod:Add("icons", defs.ITEMS_DPS_PHYSICAL, (GetItemInfo(77197)),
    format([[
    return IconAura("HELPFUL","player","%s")
    ]], spells["Combat Trance"].name))
    
    --DS Legendaries
    mod:Add("icons", defs.ITEMS_DPS_PHYSICAL, spells["DS Legendaries"].name,
    format([[
    return IconMAura("HELPFUL","player","%s","%s","%s")
    ]], spells["Shadows of the Destroyer"].name,
    spells["Nightmare"].name, spells["Suffering"].name))

    mod:Add("icons", defs.ITEMS_DPS_PHYSICAL,
    spells["Fury of the Destroyer"].name,
    format([[
    return IconAura("HELPFUL","player","%s")
    ]], spells["Fury of the Destroyer"].name))

    -- Generic Rogue -------------------------------------------------
    local basic_cds = clcInfo_Rogue.basic_cds
    -- get the localized names and make cd templates  
    for key, value in pairs(basic_cds) do
        name = GetSpellInfo(value)
        if not name then name = "Unknown Spell" end
        mod:Add("icons", defs.CLASS, name, format([[
        return IconSpell("%s")
        ]], name))
    end
    
    --Anticipation
    name = spells["Anticipation"].name
    mod:Add("icons", defs.CLASS, name, format([[
    return IconAura("HELPFUL", "player", "%s")
    ]], name))
    
    --Weakened Armor
    name = spells["Weakened Armor"].name
    mod:Add("icons", defs.CLASS, name, format([[
    return IconAura("HARMFUL", "target", "%s")
    ]], name))

    -- Assassination--------------------------------------------------
    name = spells["Blindside"].name
    mod:Add("icons", defs.CLASS_1, name, format([[
    return IconAura("HELPFUL", "player", "%s")  
    ]], name))
    
    name = spells["Vendetta"].name
    mod:Add("icons", defs.CLASS_1, name, format([[
    return IconSpell("%s")  
    ]], name))
    
    -- Combat---------------------------------------------------------
    -- Adrenaline Rush
    -- Turn icon yellow if energy >= COMBAT_MAX_NRG_SPECIALS
    name = spells["Adrenaline Rush"].name
    mod:Add("icons", defs.CLASS_2, name, format([[
    local visible, texture, start, duration, enable, reversed, count, alpha
           = IconSpell("%s", true, ready)
    if UnitPower("player") < %d and (UnitAura("player", "%s", nil, "PLAYER|HELPFUL"))
    then
        return visible, texture, start, duration, enable, reversed, count, alpha
    else
        return visible, texture, start, duration, enable, reversed, count,
               alpha, true, 0.8, 0.8, 0.1, 1
    end   
    ]], name, clcInfo_Rogue.COMBAT_MAX_NRG_SPECIALS,
        spells["Shadow Blades"].name))
    
    --Blade Flurry
    name = spells["Blade Flurry"].name
    mod:Add("icons", defs.CLASS_2, name, format([[
    return IconAura("HELPFUL","player","%s")
    ]], name))

    -- Killing Spree
    -- Turn icon yellow if energy >= COMBAT_MAX_NRG_SPECIALS
    name = spells["Killing Spree"].name
    mod:Add("icons", defs.CLASS_2, name, format([[
    local visible, texture, start, duration, enable, reversed, count, alpha
            = IconSpell("%s", true, ready)
    if UnitPower("player") < %d then
        return visible, texture, start, duration, enable, reversed, count, alpha
    else
        return visible, texture, start, duration, enable, reversed, count,
               alpha, true, 0.8, 0.8, 0.1, 1
    end   
    ]], name, clcInfo_Rogue.COMBAT_MAX_NRG_SPECIALS))
    
    -- Insight
    mod:Add("icons", defs.CLASS_2, spells["Bandit's Guile"].name, format([[
    return IconMAura("HELPFUL|PLAYER", "player", "%s", "%s", "%s")
    ]], spells["Shallow Insight"].name, spells["Moderate Insight"].name,
    spells["Deep Insight"].name))
    
    --Subtlety---------------------------------------------------------
    --Hemo
    name = spells["Hemorrhage"].name
    mod:Add("icons", defs.CLASS_3, name, format([[
    return IconAura("HARMFUL|PLAYER", "target", "%s")
    ]], name))
    
    --Premeditation
    name = spells["Premeditation"].name
    mod:Add("icons", defs.CLASS_3, name, format([[
    return IconSpell("%s")  
    ]], name))    
    
    --Shadow Dance
    name = spells["Shadow Dance"].name
    mod:Add("icons", defs.CLASS_3, name, format([[
    return IconSpell("%s")  
    ]], name))

    --Bars------------------------------------------------------------
    -- Generic Rogue --------------------------------------------------
    
    --Deadly Poison
    name = spells["Deadly Poison"].name
    mod:Add("bars", defs.CLASS, name, format([[
    return BarAura("HARMFUL|PLAYER", "target", "%s", nil, false, true)
    ]], name))
    
    --Energy
    name = ENERGY
    mod:Add("bars", defs.CLASS, name, format([[
    local nrg = UnitPower("player")
    return true, "Interface/ICONS/INV_Sigil_Thorim", 0, UnitPowerMax("player"),
           nrg, nil, "%s", nil, nrg
    ]], name))  
    
    --Recuperate
    name = spells["Recuperate"].name
    mod:Add("bars", defs.CLASS, name, format([[
    return BarAura("HELPFUL", "player", "%s", nil, false, true)
    ]], name))
    
    --Rupture
    name = spells["Rupture"].name
    mod:Add("bars", defs.CLASS, name, format([[
    return BarAura("HARMFUL|PLAYER", "target", "%s", nil, false, true)
    ]], name))
    
    --Slice and Dice
    name = spells["Slice and Dice"].name
    mod:Add("bars", defs.CLASS, name, format([[
    return BarAura("HELPFUL", "player", "%s", nil, false, true)
    ]], name))

    --Weakened Armor
    name = spells["Weakened Armor"].name
    mod:Add("bars", defs.CLASS, name, format([[
    return BarAura("HARMFUL", "target", "%s", nil, true, true)
    ]], name))
    
    -- Assassination--------------------------------------------------
    name = spells["Envenom"].name
    mod:Add("bars", defs.CLASS_1, name, format([[
    return BarAura("HELPFUL", "player", "%s", nil, false, true)  
    ]], name))
    
    name = spells["Overkill"].name
    mod:Add("bars", defs.CLASS_1, name, format([[
    return BarAura("HELPFUL", "player", "%s", nil, false, true)  
    ]], name))
    
    name = spells["Vendetta"].name
    mod:Add("bars", defs.CLASS_1, name, format([[
    return BarAura("HARMFUL|PLAYER", "target", "%s", nil, false, true)  
    ]], name))
    
    -- Combat---------------------------------------------------------
    --Adrenaline Rush
    name = spells["Adrenaline Rush"].name
    mod:Add("bars", defs.CLASS_2, name, format([[
    return BarAura("HELPFUL", "player", "%s", nil, false, true)
    ]], name))
    
    --Shallow Insight
    name = spells["Shallow Insight"].name
    mod:Add("bars", defs.CLASS_2, name, format([[
    return BarAura("HELPFUL", "player", "%s", nil, false, true)
    ]], name))
    
    --Moderate Insight
    name = spells["Moderate Insight"].name
    mod:Add("bars", defs.CLASS_2, name, format([[
    return BarAura("HELPFUL", "player", "%s", nil, false, true)
    ]], name))    
    
    --Deep Insight
    name = spells["Deep Insight"].name
    mod:Add("bars", defs.CLASS_2, name, format([[
    return BarAura("HELPFUL", "player", "%s", nil, false, true)
    ]], name))
 
    --Revealing Strike
    name = spells["Revealing Strike"].name
    mod:Add("bars", defs.CLASS_2, name, format([[
    return BarAura("HARMFUL|PLAYER", "target", "%s", nil, false, true)
    ]], name))
    
    -- Subtlety-------------------------------------------------------
    --Find Weakness
    name = spells["Find Weakness"].name
    mod:Add("bars", defs.CLASS_3, name, format([[
    return BarAura("HARMFUL|PLAYER", "target", "%s", nil, false, true)
    ]], name))
    
    --Hemo
    name = spells["Hemorrhage"].name
    mod:Add("bars", defs.CLASS_3, name, format([[
    return BarAura("HARMFUL|PLAYER", "target", "%s", nil, false, true)
    ]], name))

    --Master of Subtlety
    name = spells["Master of Subtlety"].name
    mod:Add("bars", defs.CLASS_3, name, format([[
    return BarAura("HELPFUL", "player", "%s", nil, false, true)
    ]], name))
    
    --Shadow Dance
    name = spells["Shadow Dance"].name
    mod:Add("bars", defs.CLASS_3, name, format([[
    return BarAura("HELPFUL", "player", "%s", nil, false, true)
    ]], name))
    
    --Multi Icons------------------------------------------------------------
    --Combo Points
    -- To make this look its best, the user needs to go to the General tab,
    -- set "Use Skin From" to "Self", decrease spacing, and then go to
    -- the "Skin" tab and select "BareBone"
    name = COMBAT_TEXT_SHOW_COMBO_POINTS_TEXT
    mod:Add("micons", defs.CLASS, name, format([[
    local cp = GetComboPoints("player")
    for i = 1, cp do AddMIcon(nil, true, "Interface/COMMON/Indicator-Yellow", 0,
                              0, 1, nil, nil, 1.0, true, 1, 1-((i-1)*0.25), 0,
                              1.0) end
    ]]))
    
  
    -- Priorities
    ----------------------------------------------------------------------------
    -- Assassination Priorities
    local _, specialization_name = GetSpecializationInfo(1)
    mod:Add("icons", defs.CLASS_1, format("%s %s: %s", specialization_name,
            COMBATLOG_HIGHLIGHT_ABILITY, REFORGE_CURRENT),
            "return IconAssassinationCurrent()")
    mod:Add("icons", defs.CLASS_1, format("%s %s: %s", specialization_name,
            COMBATLOG_HIGHLIGHT_ABILITY, NEXT), "IconAssassinationNext()")

    -- Combat Priorities
    _, specialization_name = GetSpecializationInfo(2)
    mod:Add("icons", defs.CLASS_2, format("%s %s: %s", specialization_name,
            COMBATLOG_HIGHLIGHT_ABILITY, REFORGE_CURRENT),
            "return IconCombatCurrent()")
    mod:Add("icons", defs.CLASS_2, format("%s %s: %s", specialization_name,
            COMBATLOG_HIGHLIGHT_ABILITY, NEXT), "IconCombatNext()")
   
    -- Subtlety Priorities
    _, specialization_name = GetSpecializationInfo(3)
    mod:Add("icons", defs.CLASS_3, format("%s %s: %s", specialization_name,
            COMBATLOG_HIGHLIGHT_ABILITY, REFORGE_CURRENT),
            "return IconSubtletyCurrent()")
    mod:Add("icons", defs.CLASS_3, format("%s %s: %s", specialization_name,
            COMBATLOG_HIGHLIGHT_ABILITY, NEXT), "IconSubtletyNext()")
end